# coding: utf-8
# vim: set fdm=indent ts=4 sw=4 sts=4 et tw=80 ai cc=+0 mouse=a nu :

from setuptools import setup, Extension, find_packages
from distutils.file_util import copy_file

from distutils.command.build import build as _build
from setuptools.command.build_ext import build_ext as _build_ext
from setuptools.command.install import install as _install
from distutils.command.clean import clean as _clean

import subprocess
import traceback
import os
import sys
import glob
sys.path.insert(0, "msspec")

from version import __version__

with open('setup_requirements.txt', 'r') as fd:
    SETUP_REQUIREMENTS = fd.read().strip().split('\n')

with open('requirements.txt', 'r') as fd:
    REQUIREMENTS = fd.read().strip().split('\n')

if __name__ == "__main__":
    setup(name='msspec',
        version=__version__,
        include_package_data=True,
        packages=find_packages(include='msspec.*'),
        setup_requires=SETUP_REQUIREMENTS,
        install_requires=REQUIREMENTS,

        author='Didier Sébilleau, Sylvain Tricot',
        author_email='sylvain.tricot@univ-rennes1.fr',
        maintainer='Sylvain Tricot',
        maintainer_email='sylvain.tricot@univ-rennes1.fr',
        url='https://msspec.cnrs.fr',
        description=('A multiple scattering package for sepectroscopies using '
                     'electrons to probe materials'),
        long_description="""MsSpec is a Fortran package to compute the
        cross-section of several spectroscopies involving one (or more)
        electron(s) as the probe. This package provides a python interface to
        control all the steps of the calculation.
   
        Available spectroscopies:
           * Photoelectron diffraction
           * Auger electron diffraction
           * Low energy electron diffraction
           * X-Ray absorption spectroscopy
           * Auger Photoelectron coincidence spectroscopy
           * Computation of the spectral radius""",
        download_url='https://msspec.cnrs.fr/downloads.html',
        # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
        classifiers=[
          'Development Status :: 3 - Alpha',
          'Environment :: Console',
          'Intended Audience :: Science/Research',
          'License :: OSI Approved :: GNU General Public License (GPL)',
          'Natural Language :: English',
          'Operating System :: Microsoft :: Windows :: Windows 10',
          'Operating System :: POSIX :: Linux',
          'Operating System :: MacOS :: MacOS X',
          'Programming Language :: Fortran',
          'Programming Language :: Python :: 3 :: Only',
          'Topic :: Scientific/Engineering :: Physics',
          ],
        keywords='spectroscopy atom electron photon multiple scattering',
        license='GPL',
          )
